#!/usr/bin/env python2

DESCRIPTION = """\
pynfs is a collection of tools and libraries for NFS4. It includes
a NFS4 library, a commandline client and a server test application.
"""

import os, sys
from distutils.core import setup, Extension

# Create list of module files under nfs4st
DIRLIST = os.listdir("nfs4st")
DIRLIST.remove("__init__.py")
DIRLIST.remove("test_tree.py")
MODLIST = ["nfs4st."+name[:-3] for name in DIRLIST if name.endswith(".py")]

# Generate some needed files
# FRED - make this run only if generated files are outdated
import rpcgen
rpcgen.run("nfs4.x")

# Describes how to compile gssapi.so - change this as needed
# FRED - is there a general way to look this info up?
gssapi = Extension('gssapi',
                   extra_compile_args = ['-Wall'],
                   include_dirs = ['/usr/kerberos/include'],
                   libraries = ['gssapi_krb5'],
                   library_dirs = ['/usr/kerberos/lib'],
                   sources = ['gssapimodule.c'])


setup(name = "pynfs",
      version = "0.3.1",
      license = "GPL",
      description = "Python NFS4 tools",
      long_description = DESCRIPTION,
      author = "Peter strand",
      author_email = "peter@cendio.se",
      maintainer = "Fred Isaman",
      maintainer_email = "iisaman@citi.umich.edu",
      #url = "http://www.cendio.se/~peter/pynfs/",
      url = "http://www.citi.umich.edu/projects/nfsv4/pynfs/",
      ext_modules = [gssapi],
      py_modules = ["nfs4constants",
                    "nfs4packer",
                    "nfs4types",
                    "rpc",
                    "nfs4lib",
                    "xdrlib",
                    "nfs4state",
                    "pynfs_completer"] + MODLIST,
      scripts = ["nfs4client.py",
                 "nfs4server.py",
                 "nfs4stest.py",
                 "test_tree_net.py"])


PATHHELP = """\

See http://www.python.org/doc/current/inst/search-path.html for detailed
information on various ways to set the search path.
One easy way is to set the environment variable PYTHONPATH.
"""
if "install" in sys.argv:
    print PATHHELP
